var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { AbstractPeer, PeerMessageType, encodeBinaryPeerMessage, decodeBinaryPeerMessage, DisconnectReason } from 'ataraxia/transport';
/**
 * Abstract implementation of a peer suitable for use with a WebSocket
 * instance.
 */
export class AbstractWebSocketPeer extends AbstractPeer {
    constructor(parent, socket) {
        super(parent);
    }
    setSocket(socket) {
        this.socket = socket;
        socket.binaryType = 'arraybuffer';
        socket.addEventListener('message', event => {
            if (!(event.data instanceof ArrayBuffer)) {
                // We only work with ArrayBuffer
                return;
            }
            const decoded = decodeBinaryPeerMessage(event.data);
            if (decoded) {
                this.receiveData(decoded[0], decoded[1]);
            }
        });
        socket.addEventListener('error', () => {
            if (socket === this.socket) {
                this.handleDisconnect(DisconnectReason.Error, new Error('Disconnecting due to error'));
            }
        });
        socket.addEventListener('close', () => {
            if (this.socket) {
                // Unknown disconnect reason
                this.handleDisconnect(DisconnectReason.Error);
            }
        });
    }
    requestDisconnect(reason, err) {
        if (!this.socket) {
            return;
        }
        const socket = this.socket;
        this.handleDisconnect(reason, err);
        socket.close();
    }
    disconnect() {
        super.disconnect();
        if (!this.socket) {
            return;
        }
        const socket = this.socket;
        this.handleDisconnect(DisconnectReason.Manual);
        socket.close();
    }
    handleDisconnect(reason, err) {
        this.socket = undefined;
        super.handleDisconnect(reason, err);
    }
    send(type, payload) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.socket) {
                this.debug('No socket but tried to send', type, 'with data', payload);
                return;
            }
            this.debug('Sending', PeerMessageType[type], 'with data', payload);
            const data = encodeBinaryPeerMessage(type, payload);
            this.socket.send(data);
        });
    }
}
//# sourceMappingURL=AbstractWebSocketPeer.js.map