import { AbstractWebSocketPeer } from './AbstractWebSocketPeer';
export class WebSocketClientPeer extends AbstractWebSocketPeer {
    constructor(parent, factory, url) {
        super(parent);
        this.factory = factory;
        this.url = url;
    }
    handleDisconnect(reason, err) {
        // If we are already waiting for a connection ignore this call
        if (this.connectTimeout)
            return;
        super.handleDisconnect(reason, err);
        // TODO: Smarter back-off algorithm
        const retryTime = 30000;
        this.debug('Reconnecting in', retryTime, 'ms');
        this.connectTimeout = setTimeout(() => this.tryConnect(), retryTime);
    }
    tryConnect() {
        // Make sure to clear the connection timeout when attempting to reconnect
        clearTimeout(this.connectTimeout);
        this.connectTimeout = null;
        // Create and setup the new WebSocket
        const ws = this.factory(this.url);
        ws.addEventListener('open', () => {
            this.debug('Connected');
            this.negotiateAsClient();
        });
        this.setSocket(ws);
    }
    disconnect() {
        super.disconnect();
        clearTimeout(this.connectTimeout);
    }
}
//# sourceMappingURL=WebSocketClientPeer.js.map