var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { AbstractTransport } from 'ataraxia/transport';
import { WebSocketClientPeer } from './WebSocketClientPeer';
export class WebSocketClientTransport extends AbstractTransport {
    constructor(options) {
        super('ws-client');
        this.options = options;
    }
    start(options) {
        const _super = Object.create(null, {
            start: { get: () => super.start }
        });
        return __awaiter(this, void 0, void 0, function* () {
            const started = yield _super.start.call(this, options);
            if (!started)
                return false;
            const factory = this.options.webSocketFactory
                || defaultWebSocketFactory;
            this.peer = new WebSocketClientPeer(this.network, factory, this.options.url);
            this.addPeer(this.peer);
            // Start connecting to the peer
            this.peer.tryConnect();
            return true;
        });
    }
    stop() {
        const _super = Object.create(null, {
            stop: { get: () => super.stop }
        });
        return __awaiter(this, void 0, void 0, function* () {
            const stopped = yield _super.stop.call(this);
            if (!stopped)
                return false;
            if (this.peer) {
                this.peer.disconnect();
            }
            return true;
        });
    }
}
function defaultWebSocketFactory(url) {
    if (typeof WebSocket !== 'object') {
        throw new Error('No default WebSocket implementation found');
    }
    return new WebSocket(url);
}
//# sourceMappingURL=WebSocketClientTransport.js.map